import { useState, useEffect } from "react";
import { Link, useLocation, useNavigate } from "react-router-dom";
import { FaTasks, FaCog, FaSignOutAlt } from "react-icons/fa";
import axios from "axios";
import { FiMenu, FiX } from "react-icons/fi";

const Sidebar = () => {
  const location = useLocation(); // Get current route path
  const navigate = useNavigate(); // Navigation hook
  const [isOpen, setIsOpen] = useState(false);

  const handleLogout = async () => {
    try {
      await axios.post("http://localhost:5000/api/auth/logout", {}, { withCredentials: true });
      document.cookie = "session_token=; expires=Thu, 01 Jan 1970 00:00:00 UTC; path=/;";
      navigate("/");
    } catch (err) {
      console.error("Logout failed:", err);
    }
  };

  // Automatically close the sidebar when the route changes
  useEffect(() => {
    setIsOpen(false);
  }, [location.pathname]);

  return (
    <>
      {/* Mobile Toggle Button */}
      <button
        onClick={() => setIsOpen(true)}
        className="md:hidden p-2 fixed top-4 left-4 z-50 bg-white shadow-lg rounded-lg"
      >
        <FiMenu size={24} />
      </button>

      {/* Backdrop for Mobile */}
      {isOpen && (
        <div
          className={`fixed inset-0 z-40 ${
            window.innerWidth >= 768 ? "bg-transparent" : "bg-transparent"
          }`}
          onClick={() => setIsOpen(false)}
        ></div>
      )}

      {/* Sidebar Container */}
      <div
        className={`fixed md:relative top-0 left-0 h-[80vh] md:h-[90vh] w-64 bg-white shadow-lg flex flex-col p-6 rounded-2xl md:ml-4 md:mt-4 md:mb-4 transition-transform transform ${
          isOpen ? "translate-x-0" : "-translate-x-full"
        } md:translate-x-0 z-50`}
      >
        {/* Close Button for Mobile */}
        <button
          onClick={(e) => {
            e.stopPropagation();
            setIsOpen(false);
          }}
          className="md:hidden p-2 self-end z-50"
        >
          <FiX size={24} />
        </button>

        {/* Logo Section */}
        <div className="flex items-center space-x-2 mb-10">
          <div className="bg-[#136D5E] text-white w-10 h-10 flex items-center justify-center rounded-2xl text-lg font-bold">
            O
          </div>
          <h2 className="text-xl font-bold text-gray-900">OMPOI</h2>
        </div>

        {/* Navigation Menu */}
        <nav className="flex flex-col gap-4">
          <Link
            to="/dashboard"
            className={`flex items-center space-x-3 px-4 py-2 rounded-lg ${
              location.pathname === "/dashboard"
                ? "bg-[#136D5E] text-white font-semibold"
                : "text-gray-600 hover:text-green-700 hover:bg-transparent"
            }`}
          >
            <img src="/assets/path288.png" alt="Agent Task" className="w-5 h-5" />
            <span>DashBoard</span>
          </Link>

          <Link
            to="/add-agent"
            className={`flex items-center space-x-3 px-4 py-2 rounded-lg ${
              location.pathname === "/add-agent"
                ? "bg-[#136D5E] text-white font-semibold"
                : "text-gray-600 hover:text-green-700 hover:bg-transparent"
            }`}
          >
            <img src="/assets/path288.png" alt="Agent Task" className="w-5 h-5" />
            <span>Agent Task</span>
          </Link>

          <Link
            to="/assign-task"
            className={`flex items-center space-x-3 px-4 py-2 rounded-lg ${
              location.pathname === "/assign-task"
                ? "bg-[#136D5E] text-white font-semibold"
                : "text-gray-600 hover:text-green-700 hover:bg-transparent"
            }`}
          >
            <FaTasks />
            <span>Assign Task</span>
          </Link>

          <Link
            to="/settings"
            className={`flex items-center space-x-3 px-4 py-2 rounded-lg ${
              location.pathname === "/settings"
                ? "bg-[#136D5E] text-white font-semibold"
                : "text-gray-600 hover:text-green-700 hover:bg-transparent"
            }`}
          >
            <FaCog />
            <span>Settings</span>
          </Link>
        </nav>

        {/* Admin Info + Logout Button */}
        <div className="mt-auto flex flex-col space-y-3">
          <div className="flex items-center space-x-3 p-4 border-t">
            <img
              src="/assets/chillguy-gID_7.webp"
              alt="Admin"
              className="w-10 h-10 rounded-full"
            />
            <div>
              <p className="text-sm font-semibold">Master Admin</p>
              <p className="text-xs text-gray-500">Admin@ompoi.com</p>
            </div>
          </div>

          {/* 🔴 Logout Button */}
          <button
            onClick={handleLogout}
            className="flex items-center space-x-3 px-4 py-2 rounded-lg bg-red-500 text-white font-semibold hover:bg-red-700"
          >
            <FaSignOutAlt />
            <span>Logout</span>
          </button>
        </div>
      </div>
    </>
  );
};

export default Sidebar;
